Welcome to fumi's documentation!
================================

Fumi is a small and (hopefully) simple deployment tool.

**Released under the MIT license.**

Source code available at `<https://github.com/rmed/fumi>`_.


Installation
------------

Fumi is available in the Python Package Index. In order to install it, you can
use **pip**::

    pip install fumi

In addition, the following dependencies will be installed:

- blessings
- paramiko
- pyyaml
- scp
- six

Contents
--------

.. toctree::
   :hidden:

   self

.. toctree::
   :maxdepth: 1

   quickstart
   deployment_file


.. toctree::
   :maxdepth: 4

   fumi


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

